package dbtypes

import (
	"database/sql"
	"errors"
)

type UserType int

const  (
    User_Normal UserType = iota + 1
    User_Admin
)

type User struct {
	Id        string
	Username  string
	Email     string
	UserType int
}

var ErrUserNotFound = errors.New("User Not found")

func UserFromToken(db *sql.DB, token string) (*User, error) {
	rows, err := db.Query("select users.id, users.username, users.email, users.user_type from users inner join tokens on tokens.user_id = users.id where tokens.token = $1;", token)
	if err != nil {
		return nil, err
	}
    defer rows.Close()

	var id string
	var username string
	var email string
	var user_type int

	if !rows.Next() {
		return nil, ErrUserNotFound
	}

	err = rows.Scan(&id, &username, &email, &user_type)
	if err != nil {
		return nil, err
	}

	return &User{id, username, email, user_type}, nil
}
